function [Wk,vec_P_err_app,vec_J,vec_w]=discriminateur_logistique_Ns(X,d,nb_boucle,lambda,Wk)
%
% [Wk,vec_P_err,vec_J,vec_w]=discriminateur_logistique_Ns(X,d,nb_boucle,lambda,Wk);
%
% entrees
%========
% X : matrice de taille NxP contenant P vecteur
% d : vecteur colonne de taille P
% nb_boucle : nombre d'itrations dans le gradient
% lambda : pas du gradient
%
% sorties
%========
% w : vecteur colonne de taille N
% vec_J : valeur du critere
%
% Critre d'arrt : quand la probabilit d'erreur sur la base
% d'apprentissage ne bouge plus pendant 5 itrations, on arrte les
% itrations.
%

d=d(:);
Ns=length(unique(d));

if nargin<=2
    nb_boucle=0;
end
if nargin<=3
    lambda=0.01;
end
%
N=size(X,1);
%
% initialisation
if nargin<=4
    Wk=rand(N,Ns);
end
%
if nargout>=2
    vec_J=zeros(1,nb_boucle);
end
if nargout>=3
    vec_w=zeros(N,Ns,nb_boucle);
end
%
vec_P_err_app=nan(1,nb_boucle);
%
for n=1:nb_boucle
    %
    % produit scalaire
    x=Wk'*X;
    %
    % calcul de la proba d'erreur sur la base d'apprentissage
    [~,d_est]=max(x);
    vec_P_err_app(n)=1-mean(d(:)==d_est(:));
    %
    for k=1:Ns
        w=Wk(:,k);
        %
        % calcul du gradient
        %
        x=X'*w;
        %
        dk=-ones(size(d));
        dk(d==k)=1;
        %
        y=exp(x);
        %
        z=y.^((1-dk)/2);
        z=dk.*z./(1+y);
        %
        % dbuggage
        z(find(isinf(y).*(d==-1)))=-1;
        %
        if max(isnan(z))==1
            disp('pb dans logistique')
            disp('save DEBUG_logistique')
            save DEBUG_logistique
            disp('pause')
            pause
        end
        %
        grad=X*z;
        %
        w=w+lambda*grad;
        %
        Wk(:,k)=w;
        if nargout>=2
            %vec_J(n)=(1+d')/2*log1+(1-d')/2*log2;
            %
            log1=log(y./(1+y));
            log2=log(1./(1+y));
            log1(isinf(y))=0;
            vec=log1;
            vec(dk==-1)=log2(dk==-1);
            %
            if k==1
                J=0;
            end
            J=J+sum(vec);
        end
    end
    %
    if nargout>=2
        vec_J(n)=J;
    end
    %
    if nargout>=3
        vec_w(:,:,n)=Wk;
    end
end

