function [d_est,Px_sachant_omegaj]=discriminateur_stat(X,cell_mu,cell_Gamma)
%
% [d_est,Px_sachant_omegaj]=discriminateur_stat(X,cell_mu,cell_Gamma);
%
% entrees
%========
% X est une matrice de taille NxP qui contient les differents vecteurs de la base
% cell_mu est une cellule qui contient les objets a detecter
% cell_Gamma est une cellule qui contient les matrices de covariance
%
% sorties
%========
% d_est est un vecteur de taille P qui contient la classe estimee

% P : nombre d'elements dans la base
[N,P]=size(X);
% nb_classe : nombre de classes
nb_classe=length(cell_mu);
%
% seuil pour le calcul de l'inverse (ou de la pseudo-inverse)
seuil=eps;
%
% intialisation de la log-vraisemblance
log_Px_sachant_omegaj=-1/seuil*ones(nb_classe,P);
%
for classe=1:nb_classe
    %
    if iscell(cell_Gamma)
        % estimateur quadratique
        Gamma=cell_Gamma{classe};
    else
        % estimateur lineaire
        Gamma=cell_Gamma;
    end
    mu=cell_mu{classe};
    %
    if ~isnan(Gamma)
        %
        % calcul de la log-vraisemblance
        %
        [u,s]=svd(Gamma);
        %
        if s(end,end)/s(1,1)<seuil
            log_det_Gamma=length(Gamma)*log(seuil);
            %
            diag_s=diag(s);
            diag_s_pm1demi=1./sqrt(diag_s(diag_s>seuil));
            r=length(diag_s_pm1demi);
            %
            Gammapmud=u(:,1:r)*diag(diag_s_pm1demi)*u(:,1:r)';
        else
            log_det_Gamma=sum(log(diag(s)));
            Gammapmud=u*diag(diag(s).^(-1/2))*u';
        end
        %
        if isreal(X)
            Y=Gammapmud*(X-mu*ones(1,P));
            vec_trace=sum(Y.^2);
            %
            log_Px_sachant_omegaj(classe,:)=-0.5*vec_trace.' ...
                -0.5*(log_det_Gamma+N*log(2*pi));
        else
            Y=Gammapmud*(X-mu*ones(1,P));
            vec_trace=sum(abs(Y).^2);
            %
            log_Px_sachant_omegaj(classe,:)=-vec_trace.' ...
                -log_det_Gamma-N*log(pi);
        end
        %
    end
end
%
[~,d_est]=max(log_Px_sachant_omegaj);
d_est=d_est(:);
%
if nargout==2
    Px_sachant_omegaj=exp(log_Px_sachant_omegaj);
end
%
end