function [mat_W_j,mat_W_k,vec_J]=estime_Wj_Wk_perceptron(Xapp,dapp,Nc,Ns,choix_offset_CE,choix_offset_CC,eta,mat_W_j,mat_W_k)
%
% [Wj,Wk,vec_J]=estime_Wj_Wk_perceptron(Xapp,dapp,Nc,Ns,choix_offset_CE,choix_offset_CC,eta,Wj,Wk);
%
% Perceptron avec 1 couche cachee
%
% Xapp : vecteur de la base d'apprentissage
% dapp : classe de chacun des vecteurs
% Nc : nombre de neurones dans la couche cachee

% N : dimension des vecteurs d'observation X
% Papp : nombre d'elements dans la base d'apprentissage.
[N,Papp]=size(Xapp);
%
% valeurs possibles prise par le vecteur indiquant la classe (1, 2, 3, ...)
unique_dapp=unique(dapp);
nb_classe=length(unique_dapp);
%
% parametres du percetron
%========================
%
if nargin<=7
    [mat_W_j,mat_W_k] = initialise_W(N,Nc,Ns,choix_offset_CE,choix_offset_CC);
end
%
% On ajoute un offset dans la couche d'entree :
if choix_offset_CE==1
    mat_X=[ones(1,Papp);Xapp];
else
    mat_X=Xapp;
end
%
% vec_t_k : vecteur "cible" pour le calcul de du critere J (et donc du gradient)
if Ns==1
    if nb_classe>2
        disp('en general quand on a plus que deux classes,')
        disp('on choisit un nombre de neurone de sortie plus grand que 1')
        return
    else
        % le neurone de sortie doit valeur 1 pour la classe 1 et -1 sinon
        mat_t_k=-ones(1,length(dapp));
        mat_t_k(dapp==unique_dapp(1))=1;
    end
else
    if nb_classe==Ns % en particulier pour le cas nb_classe==3
        % le neurone de sortie nek doit valeur 1 pour la classe n_j et -1 sinon
        mat_t_k=-ones(Ns,length(dapp));
        %
        for n=1:nb_classe
            mat_t_k(n,dapp==unique_dapp(n))=1;
        end
    else
        disp('pas fini')
        disp('je n''ai pas reflechi a cette possibilite')
        return
    end
end
%
if nargout==3
    vec_J=nan(1,Papp);
end
% stochastic Backpropagation (voir Duda)
vec_ordre=randperm(Papp);
%
for i=1:Papp
    %
    ind_X=vec_ordre(i);
    %
    % Propagation dans le perceptron
    %===============================
    %
    % vec_x est le vecteur a N+1 variables
    vec_x=mat_X(:,ind_X);
    % vec_nu_j est le vecteur des Nc variables tel que y_j=f(nu_j)
    vec_nu_j=mat_W_j.'*vec_x;
    %
    % pour avoir un neurones qui renvoie n'importe quoi
    %vec_nu_j(end)=randn;
    %
    % vec_y_j est le vecteur des sorties de la couche des neurones caches
    vec_y_j=sigmoide(vec_nu_j);
    if choix_offset_CC==1
        % on ajoute l'offset
        vec_yy_j=[1;vec_y_j];
    else
        vec_yy_j=vec_y_j;
    end
    % vec_eta_k est le vecteur des variables tel que z_k=f(eta_k)
    vec_eta_k=mat_W_k.'*vec_yy_j;
    % vec_z_k est le vecteur des sorties de la couche de sortie
    vec_z_k=sigmoide(vec_eta_k);
    %
    % Retro-propagation pour le calcul du gradient
    %=============================================
    % vec_t_k : vecteur "cible"
    vec_t_k=mat_t_k(:,ind_X);
    %
    % delta_k = - \frac{\partial J}{\partial \eta_k}
    vec_delta_k=(vec_t_k-vec_z_k).*sigmoide_prime(vec_eta_k);
    % Delta_wkj ou w_kj (entre couche cachee et couche de sortie)
    mat_Delta_wkj=eta*vec_yy_j*vec_delta_k.';
    %
    % delta_j : parametre temporaire
    if choix_offset_CC==1
        vec_delta_j=sigmoide_prime(vec_nu_j).*(mat_W_k(2:end,:)*vec_delta_k);
    else
        vec_delta_j=sigmoide_prime(vec_nu_j).*(mat_W_k*vec_delta_k);
    end
    % Delta_wji ou w_ji (entre les entrees et la couche cachee)
    mat_Delta_wji=eta*vec_x*vec_delta_j.';
    %
    % MAJ de mat_W_j
    mat_W_j=mat_W_j+mat_Delta_wji;
    % MAJ de mat_W_k
    mat_W_k=mat_W_k+mat_Delta_wkj;
    %
    if nargout==3
        % Calcul du critere J
        %
        mat_NU_j=mat_W_j.'*mat_X;
        mat_Y=sigmoide(mat_NU_j);
        if choix_offset_CC==1
            mat_NU_k=mat_W_k.'*[ones(1,Papp);mat_Y];
        else
            mat_NU_k=mat_W_k.'*mat_Y;
        end
        mat_Z=sigmoide(mat_NU_k);
        J=1/(4*Papp)*sum((mat_Z(:)-mat_t_k(:)).^2);
        %
        if max(isnan(J))
            disp('NaN dans J')
            disp('save DEBUG_RN5')
            save DEBUG_RN5
            disp('pause')
            pause
        end
        vec_J(ind_X)=J;
    end
end
%
1;