function [cell_mu,cell_Gamma,choix_fusion,type_base]=genere_param_base_de_donnees(choix_base,nb_chiffres)
%
% [cell_mu,cell_Gamma,choix_fusion,type_base]=genere_param_base_de_donnees(choix_base,nb_chiffres)
%

if choix_base==0
    % 1 anneau et un centre
    %
    cell_mu=cell(1,64);
    cell_Gamma=cell_mu;
    %
    nb_C=80;
    sigma=0.03;
    phi=2*pi*(0:(nb_C-1))/nb_C;
    z=exp(1i*phi);
    for n=1:2:nb_C
        cell_mu{n}=[real(z(n));imag(z(n))];
        cell_Gamma{n}=sigma*[1 0;0 1];
    end
    %
    for n=2:2:nb_C
        cell_mu{n}=[0;0];
        cell_Gamma{n}=sigma*[1 0;0 1];
    end
    %
    choix_fusion=1;
    type_base='multi-modes';
elseif choix_base==1
    % 4 gaussiennes allongees que l'on fusionne.
    %
    sigma=3;
    cell_mu{1}=1.5*[1;1];
    cell_Gamma{1}=sigma*[1 -0.9;-0.9 1];
    cell_mu{2}=[0;0];
    cell_Gamma{2}=sigma*[1 -0.9;-0.9 1];
    cell_mu{3}=1.5*[-1;-1];
    cell_Gamma{3}=sigma*[1 -0.9;-0.9 1];
    cell_mu{4}=3*[1;1];
    cell_Gamma{4}=sigma*[1 -0.9;-0.9 1];
    %
    choix_fusion=1;
    type_base='multi-modes';
elseif choix_base==2
    % 2 spirales
    %
    cell_mu=cell(1,64);
    cell_Gamma=cell_mu;
    %
    nb_C=90;
    %sigma=0.03;
    sigma=0.09;
    phi=2*pi*(0:(nb_C-1))/nb_C;
    rho=linspace(0.5,2.5,nb_C);
    z=rho.*exp(1i*phi);
    for n=1:2:nb_C
        cell_mu{n}=[real(z(n));imag(z(n))];
        cell_Gamma{n}=sigma*[1 0;0 1];
    end
    %
    z=rho.*exp(1i*(pi+phi));
    for n=2:2:nb_C
        cell_mu{n}=[real(z(n));imag(z(n))];
        cell_Gamma{n}=sigma*[1 0;0 1];
    end
    %
    choix_fusion=1;
    type_base='multi-modes';
elseif choix_base==3
    % 2 classes avec 2 chiffres (1 et 2)
    %
    if nargin==1
        nb_chiffres=10;
    end
    %
    cell_mu=genere_chiffres;
    cell_mu=cell_mu(1:nb_chiffres);
    nb_classe=length(cell_mu);
    cell_Gamma=cell(size(cell_mu));
    N=length(cell_mu{1});
    %
    sigma=0.3;
    for c=1:nb_classe
        cell_Gamma{c}=sigma*eye(N);
    end
    %
    choix_fusion=0;
    type_base='chiffres';
elseif choix_base==4
    % 2 classes en grande dimension
    %
    N=46;
    cell_mu{1}=ones(N,1);
    cell_mu{2}=-ones(N,1);
    %
    sigma=10;
    cell_Gamma=cell(size(cell_mu));
    for n=1:length(cell_mu)
        cell_Gamma{n}=sigma*eye(N);
    end
    %
    choix_fusion=1;
    type_base='gaussiennes';
elseif choix_base==5
    % idem precedent, mas avec 10 chiffres
    %
    cell_mu=genere_chiffres;
    nb_classe=length(cell_mu);
    cell_Gamma=cell(size(cell_mu));
    N=length(cell_mu{1});
    %
    sigma=0.3;
    for c=1:nb_classe
        cell_Gamma{c}=sigma*eye(N);
    end
    %
    choix_fusion=0;
    type_base='chiffres';
elseif choix_base==6
    % 4 gaussiennes allongees que l'on fusionne.
    %
    %NZ=6;
    NZ=0;
    sigma=3;
    cell_mu{1}=1.5*[1;1;zeros(NZ,1);1;-1];
    cell_mu{2}=1.5*[0;0;zeros(NZ,1);0;0];
    cell_mu{3}=-1.5*[1;1;zeros(NZ,1);1;-1];
    cell_mu{4}=3*[1;1;zeros(NZ,1);1;-1];
    Gamma=sigma*eye(length(cell_mu{1}));
    Gamma(1,2)=-0.9*sigma;
    Gamma(2,1)=-0.9*sigma;
    Gamma(end-1,end)=0.9*sigma;
    Gamma(end,end-1)=0.9*sigma;
    for n=1:length(cell_mu)
        cell_Gamma{n}=Gamma;
    end
    %
    choix_fusion=1;
    type_base='multi-modes';
elseif choix_base==7
    %
    % XOR : 4 classes et l'on fusionne les impaires et les paires
    %
    sigma=0.1;
    %sigma=0.05;
    cell_mu{1}=[-1;-1];
    cell_mu{2}=[-1;1];
    cell_mu{4}=[1;-1];
    cell_mu{3}=[1;1];
    %cell_mu{6}=[1;2];
    %cell_mu{5}=[0;2];
    %cell_mu{7}=[2;0];
    %cell_mu{8}=[2;1];
    %cell_mu{9}=[2;2];
    for n=1:length(cell_mu)
        cell_Gamma{n}=sigma*eye(2);
    end
    %
    choix_fusion=1;
    type_base='multi-modes';
elseif choix_base==8
    % plusieurs classes, mais on fusionne
    %
    nb_C=64;
    sigma=0.02;
    phi=2*pi*(0:(nb_C-1))/nb_C;
    rho=exp(1i*phi);
    for n=1:2:nb_C
        cell_mu{n}=[real(rho(n));imag(rho(n))];
    end
    %
    phi=2*pi*(0:(nb_C-2))/(nb_C-1);
    rho=2*exp(1i*phi);
    for n=2:2:nb_C-1
        cell_mu{n}=[real(rho(n));imag(rho(n))];
    end
    cell_mu{nb_C}=[0;0];
    %
    for n=1:nb_C
        cell_Gamma{n}=sigma*[1 0;0 1];
    end
    %
    choix_fusion=1;
elseif choix_base==9
    % 2 classes
    % chacune des classe est une gaussienne
    %
    cell_mu{1}=[0;0];
    cell_Gamma{1}=0.01*eye(2);
    cell_mu{2}=[0;0];
    cell_Gamma{2}=eye(2);
    %
    choix_fusion=0;
elseif choix_base==10
    sigma=0.3;
    cell_mu{1}=[0;2];
    cell_Gamma{1}=sigma*eye(2);
    cell_mu{2}=[2;0];
    cell_Gamma{2}=sigma*eye(2);
    cell_mu{3}=[0;-2];
    cell_Gamma{3}=sigma*eye(2);
    cell_mu{4}=[-2;-0];
    cell_Gamma{4}=sigma*eye(2);
    %
    choix_fusion=0;
elseif choix_base==11
    sigma=0.3;
    cell_mu{1}=[10;0];
    cell_Gamma{1}=sigma*eye(2);
    cell_mu{2}=[0;0];
    cell_Gamma{2}=sigma*eye(2);
    cell_mu{3}=[-10;0];
    cell_Gamma{3}=sigma*eye(2);
    %
    choix_fusion=0;
end
%
